<div class="field">
    <p class="control">
        <input class="{% if widget.type != 'checkbox' %}input{% endif %} is-fullwidth"
               name="{{ widget.name }}" type="{{ widget.type }}"
               {% if widget.value != None %} value="{{ widget.value|stringformat:'s' }}"{% endif %}
               {% include "django/forms/widgets/attrs.html" %}
        >
    </p>
</div>
